<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Welcome To Spider163</title>
    <link rel="stylesheet" href="/static/css/spider163.css">
    <link href="https://cdn.bootcss.com/bootstrap/3.3.7/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<ul class="nav nav-tabs">
  <li role="presentation"><a href="/#">主页</a></li>
    <li role="presentation"><a href="/spider">抓取</a></li>
  <li role="presentation"><a href="/stat">统计</a></li>
    <li role="presentation"><a href="/scan">浏览</a></li>
    <li role="presentation"><a href="#">商业</a></li>
</ul>

<div class="brand-intro">
      <div class="sui-container">
        <h1>简单易用、功能强大的网易云音乐爬虫</h1>
        <p class="sui-lead">Spider163 是程天（GitHub:Chengyumeng,微信公众账号：程天写代码）开发的网易云音乐爬虫总库。<br>
            项目遵循 MIT 开源协议</p>
        <p class="btn-wrap">
            <a href="/spider" class="sui-btn btn-lead">抓取</a>
            <a href="/stat" class="sui-btn btn-lead">统计</a>
            <a href="/scan" class="sui-btn btn-lead">浏览</a>
            <a href="/bussiness" class="sui-btn btn-lead">商业</a>
        </p>
      </div>
    </div>

<div class="footer">
      <ul class="unstyled">
        <li>@time 2017.04.07</li>
          <li>@author 程天
              <a href="https://www.zhihu.com/people/toocooltohavefriends/activities" class="">知乎</a>
              <a href="" class="">微信</a>
              <a href="https://github.com/Chengyumeng" class="">GitHub</a></li>
      </ul>
    </div>


</body>
<script src="https://ss0.bdstatic.com/5aV1bjqh_Q23odCf/static/superman/js/lib/jquery-1.10.2_d88366fd.js"></script>
<script src="/static/js/spider163.js"></script>

</html>