<!DOCTYPE html>
<html lang="en" ng-app="spider">
<head>
    <meta charset="UTF-8">
    <title>Welcome To Spider163</title>
    <link href="http://g.alicdn.com/sj/dpl/1.5.1/css/sui.min.css" rel="stylesheet">
    <link href="https://cdn.bootcss.com/bootstrap/3.3.7/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="/static/css/spider163.css">




</head>
<body>
<ul class="nav nav-tabs">
  <li role="presentation"><a href="/#">主页</a></li>
    <li role="presentation"><a href="/spider">抓取</a></li>
  <li role="presentation"><a href="/stat">统计</a></li>
    <li role="presentation"><a href="/scan">浏览</a></li>
    <li role="presentation"><a href="/bussiness">商业</a></li>
</ul>
<div class="container index-body">
    <h2 class="m-h2 m-h2-mb">随机展示 <i>本页面未来将增加搜索功能</i></h2>
    <div class="row">
        <div class="i-c-g" id="index-group"></div>
    </div>


    <div class="process"></div>
</div>
<div class="footer">
      <ul class="unstyled">
        <li>@time 2017.04.07</li>
          <li>@author 程天
              <a href="https://www.zhihu.com/people/toocooltohavefriends/activities" class="">知乎</a>
              <a href="" class="">微信</a>
              <a href="https://github.com/Chengyumeng" class="">GitHub</a></li>
      </ul>
</div>


</body>
    <script src="https://ss0.bdstatic.com/5aV1bjqh_Q23odCf/static/superman/js/lib/jquery-1.10.2_d88366fd.js"></script>
    <script src="/static/js/scan.js"></script>
</html>