<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Welcome To Spider163</title>
    <link rel="stylesheet" href="/static/css/spider163.css">
    <link href="https://cdn.bootcss.com/bootstrap/3.3.7/css/bootstrap.min.css" rel="stylesheet">

    <link href="http://g.alicdn.com/sj/dpl/1.5.1/css/sui.min.css" rel="stylesheet">
</head>
<body>
<ul class="nav nav-tabs">
  <li role="presentation"><a href="/#">主页</a></li>
    <li role="presentation"><a href="/spider">抓取</a></li>
  <li role="presentation"><a href="/stat">统计</a></li>
    <li role="presentation"><a href="/scan">浏览</a></li>
    <li role="presentation"><a href="/bussiness">商业</a></li>
</ul>

<div class="page-header" style="padding-left:100px">
						<h2>Spider163 用户许可 和 我们的期待</h2>
</div>
<div>
    <p class="navbar-text">
        2014年1月1日起，最高人民法院在全国范围内实施裁判文书网上公开。
        这是司法改革的一项重要举措，对贯彻落实审判公开原则，促进司法公正，提升司法公信力有着深远的积极意义。<br>
        附：<a href="http://www.chinacourt.org/article/detail/2013/11/id/1152212.shtml" target="_blank">《最高人民法院关于人民法院在互联网公布裁判文书的规定》</a>
    </p>
     <p class="navbar-text">
        2014年1月1日起，最高人民法院在全国范围内实施裁判文书网上公开。
        这是司法改革的一项重要举措，对贯彻落实审判公开原则，促进司法公正，提升司法公信力有着深远的积极意义。<br>
        附：<a href="http://www.chinacourt.org/article/detail/2013/11/id/1152212.shtml" target="_blank">《最高人民法院关于人民法院在互联网公布裁判文书的规定》</a>
    </p>
</div>
</body>
</html>